@@ -28,7 +28,7 @@
 #include <unistd.h>
 #include <stdlib.h>
 
-#include <gdk/gdkscreen.h>
+#include <gdk/gdk.h>
 #include <gdk/gdkx.h>
 
 #define GROUPS_SUBMENU_PATH "/popups/popup/groups"
